==> qtjambi-remoteobjects-5.15.17-sources.jar: io/qt/remoteobjects/ClientIoDevice.java <==
package io.qt.remoteobjects;

import io.qt.*;


/**
 * <p>Java wrapper for Qt class <code>ClientIoDevice</code></p>
 */
public abstract class ClientIoDevice extends io.qt.remoteobjects.IoDeviceBase
{
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.@NonNull QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(ClientIoDevice.class);
    
    @NativeAccess
    private static final class ConcreteWrapper extends ClientIoDevice {
        
        @NativeAccess
        private ConcreteWrapper(QPrivateConstructor p) { super(p); }
        
        @Override
        @QtUninvokable
        public void connectToServer(){
            connectToServer_native(QtJambi_LibraryUtilities.internal.nativeId(this));
        }
        @QtUninvokable
        private native void connectToServer_native(long __this__nativeId);
        
        
        @Override
        @QtUninvokable
        public io.qt.core.@Nullable QIODevice connection(){
            return connection_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
        }
        @QtUninvokable
        private native io.qt.core.QIODevice connection_native_constfct(long __this__nativeId);
        
        
        @Override
        @QtUninvokable
        protected void doClose(){
            doClose_native(QtJambi_LibraryUtilities.internal.nativeId(this));
        }
        @QtUninvokable
        private native void doClose_native(long __this__nativeId);
        
        
        @Override
        @QtUninvokable
        protected void doDisconnectFromServer(){
            doDisconnectFromServer_native(QtJambi_LibraryUtilities.internal.nativeId(this));
        }
        @QtUninvokable
        private native void doDisconnectFromServer_native(long __this__nativeId);
        
    }
    

    /**
     * <p>See <code>ClientIoDevice::<wbr>shouldReconnect(ClientIoDevice*)</code></p>
     */
    public final @NonNull Signal1<io.qt.remoteobjects.@Nullable ClientIoDevice> shouldReconnect = new Signal1<>();
    
    /**
     * <p>See <code>ClientIoDevice::<wbr>ClientIoDevice(QObject*)</code></p>
     */
    public ClientIoDevice(io.qt.core.@Nullable QObject parent){
        super((QPrivateConstructor)null);
        initialize_native(this, parent);
    }
    
    private native static void initialize_native(ClientIoDevice instance, io.qt.core.QObject parent);
    
    /**
     * <p>See <code>ClientIoDevice::<wbr>disconnectFromServer()</code></p>
     */
    @QtUninvokable
    public final void disconnectFromServer(){
        disconnectFromServer_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native void disconnectFromServer_native(long __this__nativeId);
    
    /**
     * <p>See <code>ClientIoDevice::<wbr>url()const</code></p>
     */
    @QtUninvokable
    public final io.qt.core.@NonNull QUrl url(){
        return url_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native io.qt.core.QUrl url_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <code>ClientIoDevice::<wbr>connectToServer()</code></p>
     */
    @QtUninvokable
    public abstract void connectToServer();
    
    @QtUninvokable
    private native void connectToServer_native(long __this__nativeId);
    
    /**
     * <p>See <code>IoDeviceBase::<wbr>deviceType()const</code></p>
     */
    @QtUninvokable
    @Override
    protected java.lang.@NonNull String deviceType(){
        return deviceType_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native java.lang.String deviceType_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <code>ClientIoDevice::<wbr>doDisconnectFromServer()</code></p>
     */
    @QtUninvokable
    protected abstract void doDisconnectFromServer();
    
    @QtUninvokable
    private native void doDisconnectFromServer_native(long __this__nativeId);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     * @hidden
     */
    @NativeAccess
    protected ClientIoDevice(QPrivateConstructor p) { super(p); } 
    
    /**
     * Constructor for internal use only.
     * @hidden
     * It is not allowed to call the declarative constructor from inside Java.
     */
    @NativeAccess
    protected ClientIoDevice(QDeclarativeConstructor constructor) {
        super((QPrivateConstructor)null);
        initialize_native(this, constructor);
    } 
    
    @QtUninvokable
    private static native void initialize_native(ClientIoDevice instance, QDeclarativeConstructor constructor);
    
    
    /**
     * <p>Overloaded constructor for {@link #ClientIoDevice(io.qt.core.QObject)}
     *  with <code>parent = null</code>.</p>
     */
    public ClientIoDevice() {
        this((io.qt.core.QObject)null);
    }
}

==> qtjambi-remoteobjects-5.15.19-sources.jar: io/qt/remoteobjects/ClientIoDevice.java <==
package io.qt.remoteobjects;

import io.qt.*;


/**
 * <p>Java wrapper for Qt class <code>ClientIoDevice</code></p>
 */
public abstract class ClientIoDevice extends io.qt.remoteobjects.IoDeviceBase
{
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.@NonNull QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(ClientIoDevice.class);
    
    @NativeAccess
    private static final class ConcreteWrapper extends ClientIoDevice {
        
        @NativeAccess
        private ConcreteWrapper(QPrivateConstructor p) { super(p); }
        
        @Override
        @QtUninvokable
        public void connectToServer(){
            connectToServer_native(QtJambi_LibraryUtilities.internal.nativeId(this));
        }
        @QtUninvokable
        private native void connectToServer_native(long __this__nativeId);
        
        
        @Override
        @QtUninvokable
        public io.qt.core.@Nullable QIODevice connection(){
            return connection_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
        }
        @QtUninvokable
        private native io.qt.core.QIODevice connection_native_constfct(long __this__nativeId);
        
        
        @Override
        @QtUninvokable
        protected void doClose(){
            doClose_native(QtJambi_LibraryUtilities.internal.nativeId(this));
        }
        @QtUninvokable
        private native void doClose_native(long __this__nativeId);
        
        
        @Override
        @QtUninvokable
        protected void doDisconnectFromServer(){
            doDisconnectFromServer_native(QtJambi_LibraryUtilities.internal.nativeId(this));
        }
        @QtUninvokable
        private native void doDisconnectFromServer_native(long __this__nativeId);
        
    }
    

    /**
     * <p>See <code>ClientIoDevice::<wbr/>shouldReconnect(ClientIoDevice*)</code></p>
     */
    public final @NonNull Signal1<io.qt.remoteobjects.@Nullable ClientIoDevice> shouldReconnect = new Signal1<>();
    
    /**
     * <p>See <code>ClientIoDevice::<wbr/>ClientIoDevice(QObject*)</code></p>
     */
    public ClientIoDevice(io.qt.core.@Nullable QObject parent){
        super((QPrivateConstructor)null);
        initialize_native(this, parent);
    }
    
    private native static void initialize_native(ClientIoDevice instance, io.qt.core.QObject parent);
    
    /**
     * <p>See <code>ClientIoDevice::<wbr/>disconnectFromServer()</code></p>
     */
    @QtUninvokable
    public final void disconnectFromServer(){
        disconnectFromServer_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native void disconnectFromServer_native(long __this__nativeId);
    
    /**
     * <p>See <code>ClientIoDevice::<wbr/>url()const</code></p>
     */
    @QtUninvokable
    public final io.qt.core.@NonNull QUrl url(){
        return url_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native io.qt.core.QUrl url_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <code>ClientIoDevice::<wbr/>connectToServer()</code></p>
     */
    @QtUninvokable
    public abstract void connectToServer();
    
    @QtUninvokable
    private native void connectToServer_native(long __this__nativeId);
    
    /**
     * <p>See <code>IoDeviceBase::<wbr/>deviceType()const</code></p>
     */
    @QtUninvokable
    @Override
    protected java.lang.@NonNull String deviceType(){
        return deviceType_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native java.lang.String deviceType_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <code>ClientIoDevice::<wbr/>doDisconnectFromServer()</code></p>
     */
    @QtUninvokable
    protected abstract void doDisconnectFromServer();
    
    @QtUninvokable
    private native void doDisconnectFromServer_native(long __this__nativeId);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     * @hidden
     */
    @NativeAccess
    protected ClientIoDevice(QPrivateConstructor p) { super(p); } 
    
    /**
     * Constructor for internal use only.
     * It is not allowed to call the declarative constructor from inside Java.
     * @hidden
     */
    @NativeAccess
    protected ClientIoDevice(QDeclarativeConstructor constructor) {
        super((QPrivateConstructor)null);
        initialize_native(this, constructor);
    } 
    
    @QtUninvokable
    private static native void initialize_native(ClientIoDevice instance, QDeclarativeConstructor constructor);
    
    
    /**
     * <p>Overloaded constructor for {@link #ClientIoDevice(io.qt.core.QObject)}
     *  with <code>parent = null</code>.</p>
     */
    public ClientIoDevice() {
        this((io.qt.core.QObject)null);
    }
}
